@@ -25,6 +25,7 @@ this:
  >>> creator_metric = Creator('creator.csv')
  >>> creator_metric(a)
 """
+from __future__ import print_function
 import os
 import logging
 import sys
@@ -276,8 +277,9 @@ class TimeBetweenPointsAndStrokes(object):
 class AnalyzeErrors(object):
     """Analyze the number of errors in the dataset."""
 
-    def __init__(self, filename="errors.txt"):
+    def __init__(self, filename="errors.txt", time_max_threshold=30*1000):
         self.filename = prepare_file(filename)
+        self.time_max_threshold = time_max_threshold  # in ms
 
     def __repr__(self):
         return "AnalyzeErrors"
@@ -287,7 +289,6 @@ class AnalyzeErrors(object):
 
     def __call__(self, raw_datasets):
         write_file = open(self.filename, "a")
-        write_file.write("wild points,\n")  # heading
 
         # Initialize variables
         s = ""
@@ -301,12 +302,11 @@ class AnalyzeErrors(object):
         symbols_with_dots = ['i', 'j', '\cdot', '\div', '\\because',
                              '\\therefore']
         percentages = []
-        time_max_threshold = 30*1000  # Max 30 sec pro symbol
         time_max_list = []  # List with symbols that are over the time maximum
 
         for raw_dataset in raw_datasets:
             symbols[raw_dataset['handwriting'].formula_in_latex] += 1
-            if raw_dataset['handwriting'].get_time() > time_max_threshold:
+            if raw_dataset['handwriting'].get_time() > self.time_max_threshold:
                 time_max_list.append(raw_dataset['handwriting'])
             if raw_dataset['handwriting'].wild_point_count > 0:
                 wild_point_recs += 1
@@ -335,39 +335,46 @@ class AnalyzeErrors(object):
                 s += "%s (%i) \n" % (symbol, count)
             else:
                 s += "%s (%i), " % (symbol, count)
-        write_file.write("## Data")
-        write_file.write("Symbols: %i" % len(symbols))
-        write_file.write("Recordings: %i" % sum(symbols.values()))
-        write_file.write("```")
-        write_file.write(s[:-1])
-        write_file.write("```")
+        print("## Data", file=write_file)
+        print("Symbols: %i" % len(symbols), file=write_file)
+        print("Recordings: %i" % sum(symbols.values()), file=write_file)
+        print("```", file=write_file)
+        print(s[:-1], file=write_file)
+        print("```", file=write_file)
 
         # Show errors
-        write_file.write("Recordings with wild points: %i (%0.2f%%)" %
-                         (wild_point_recs,
-                          float(wild_point_recs)/len(raw_datasets)*100))
-        write_file.write("wild points: %i" % wild_points)
-        write_file.write("Recordings with missing line: %i (%0.2f%%)" %
-                         (missing_stroke_recs,
-                          float(missing_stroke_recs)/len(raw_datasets)*100))
-        write_file.write("Recordings with errors: %i (%0.2f%%)" %
-                         (recs_with_errors,
-                          float(recs_with_errors)/len(raw_datasets)*100))
-        write_file.write("Recordings with dots: %i (%0.2f%%)" %
-                         (recs_with_single_dot,
-                          float(recs_with_single_dot)/len(raw_datasets)*100))
-        write_file.write("dots: %i" % single_dots)
-        write_file.write("size changing removal: %i (%0.2f%%)" %
-                         (len(percentages),
-                          float(len(percentages))/len(raw_datasets)*100))
+        print("Recordings with wild points: %i (%0.2f%%)" %
+              (wild_point_recs,
+               float(wild_point_recs)/len(raw_datasets)*100),
+              file=write_file)
+        print("wild points: %i" % wild_points, file=write_file)
+        print("Recordings with missing line: %i (%0.2f%%)" %
+              (missing_stroke_recs,
+               float(missing_stroke_recs)/len(raw_datasets)*100),
+              file=write_file)
+        print("Recordings with errors: %i (%0.2f%%)" %
+              (recs_with_errors,
+               float(recs_with_errors)/len(raw_datasets)*100),
+              file=write_file)
+        print("Recordings with dots: %i (%0.2f%%)" %
+              (recs_with_single_dot,
+               float(recs_with_single_dot)/len(raw_datasets)*100),
+              file=write_file)
+        print("dots: %i" % single_dots)
+        print("size changing removal: %i (%0.2f%%)" %
+              (len(percentages),
+               float(len(percentages))/len(raw_datasets)*100),
+              file=write_file)
 
         time_max_list = sorted(time_max_list,
                                key=lambda n: n.get_time(),
                                reverse=True)
-        write_file.write("%i recordings took more than %i ms. That were: " %
-                         (len(time_max_list), time_max_threshold))
+        print("%i recordings took more than %i ms. That were: " %
+              (len(time_max_list), self.time_max_threshold),
+              file=write_file)
         for el in time_max_list:
             print("* %ims: %s: %s" % (el.get_time(),
                                       utils.get_readable_time(el.get_time()),
-                                      el))
+                                      el),
+                  file=write_file)
         write_file.close()
